@@ -2,7 +2,7 @@ package Data::Sah::CoerceCommon;
 
 our $DATE = '2019-11-28'; # DATE
 our $DIST = 'Data-Sah-Coerce'; # DIST
-our $VERSION = '0.037'; # VERSION
+our $VERSION = '0.038'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -140,12 +140,12 @@ sub get_coerce_rules {
     my $prefix = "Data::Sah::Coerce::$compiler\::To_$typen\::";
 
     my @rule_names = @{ $Default_Rules{$compiler}{$typen} || [] };
-    my $is_old_name;
     for my $item (@{ $args{coerce_rules} // [] }) {
         my $is_exclude = $item =~ s/\A!//;
         if ($item =~ /\A\w+\z/) {
-            $is_old_name = 1;
+            # old name
         } elsif ($item =~ /\AFrom_[A-Za-z0-9_]+::[A-Za-z0-9_]+\z/) {
+            # new name
         } else {
             die "Invalid syntax for coercion rule item '$item', please ".
                 "only use From_<type>::<description>";
@@ -159,6 +159,7 @@ sub get_coerce_rules {
 
     my @rules;
     for my $rule_name (@rule_names) {
+        my $is_old_name = $rule_name =~ /\A\w+\z/;
         my $mod = ($is_old_name ? $old_prefix : $prefix) . $rule_name;
         (my $mod_pm = "$mod.pm") =~ s!::!/!g;
         require $mod_pm;
@@ -228,7 +229,7 @@ Data::Sah::CoerceCommon - Common stuffs for Data::Sah::Coerce and Data::Sah::Coe
 
 =head1 VERSION
 
-This document describes version 0.037 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2019-11-28.
+This document describes version 0.038 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2019-11-28.
 
 =head1 FUNCTIONS
 
